View source: R/simulate-covid.R
Simulate covid for a given reproduction number, level of vaccinations in a population, and other epidemiological params.
R |
The average number of additional people an infected person will infect in an unvaccinated society. It incorporates both the R0 of the variant and behaviours and policies may reduce alter transmission. A single numeric with default 4.5 to represent the Delta variant in a low-restriction society. See Kucharski et al (2021). |
R_dist |
The distribution of the R value, each with mean equal to R. One of: "constant" (the default); "rpois" ( |
serial_interval |
The average number of days between a person becoming infected and infecting others. A single numeric with default of 5, appropriate for wild type/Delta variant: Pung et al (2021)).
A shorter |
vaccination_levels |
Starting vaccination levels. Either a single numeric for a uniformly distributed population wide vaccination rate, or a named vector of length 10 representing the vaccination levels for age groups 0-10, 11-20, 21-30, ..., 91-100. Default is |
vaccination_growth_steepness |
Defines how quickly additional people are vaccinated after opening, defaulting to 0.01. This is the growth parameter ( |
p_max_vaccinated |
Maximum proportion of the population able to be vaccinated. A single numeric with default 0.90. This is the maximium level parameter ( |
only_pfizer_after_opening |
When the simulation starts, do newly vaccinated people only get |
over60_az_share |
The proportion of vaccinated people over 60 years old who have the AstraZeneca vaccine. Single numeric defaulting to 0.80. Used for vaccine distribution before the simulation starts and, when |
under60_az_share |
The proportion of vaccinated people 60-years-old and younger who have the AstraZeneca vaccine. Single numeric defaulting to 0.10. Used for vaccine distribution before the simulation starts and, when |
kids_R_reduction |
The proportion reduction in transmission of children under the age of 18 defaulting to 0.3. |
vac_transmission_reduction |
The reduction in the likelihood of transmission from an infected vaccinated person relative to an infected unvaccinated person. A single numeric with default 0.5, representing a 50 per cent reduction in transmission from vaccinated infection people. |
death_rate |
The likelihood that an infected unvaccinated person dies by age. Either a character "loglinear", the default, which uses the log-linear relationship between age and mortality of |
treatment_death_reduction |
The reduction in mortality from treatments. A single numeric with default 0.2 that proportionally reduces |
n_population |
Population size for each simulation. A single numeric defaulting to 2.6e6 (about 10 per cent of the Australian population). |
n_start_infected |
An integer for the number of people infected at the beginning of the simulation. An integer defaulting to 100L people infected at day 0. |
n_daily_introductions |
An integer for the number of new external infections introduced each day. An integer defaulting to 1L. |
n_iterations |
Number of iterations the simulation runs for. A single integer defaulting to 3L. Means that the simulation runs for |
run_simulations |
The number of times the simulation is run. A single integer defaulting to 1L. |
scenario |
Name of the scenario. Defaults to "1". This is useful when using |
A tibble object with one row per scenario, simulation and iteration. For each row, columns provide information on:
|
The scenario name. |
|
The simulation run number. |
|
The iteration of the scenario simulation run. |
|
Days since beginning of simulation, where |
|
the number of new possible Covid cases in iteration |
|
the number of new Covid cases in iteration |
|
the number of new local transmission cases in iteration |
|
the number of new overseas/external cases introduced in iteration |
|
the number of new cases that were fully vaccinated in iteration |
|
the number of new cases hospitalised in iteration |
|
current hospital demand in iteration |
|
the number of new cases requiring ICU in iteration |
|
current ICU demand iteration |
|
the number of new Covid dead in iteration |
|
the number of new dead who were fully vaccinated in iteration |
|
the number of new people fully vaccinated in iteration |
|
the cumulative number of Covid cases after iteration |
|
the cumulative number of Covid dead after iteration |
|
the cumulative number of Covid vaccinations after iteration |
|
The average number of new infections in this iteration cased by a case in the previous iteration.Derived with |
|
Input population in the simulation, equal to the |
|
Input |
|
Input |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.